if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/ea08a008-b251-46c1-6484-797ec66d6af9/volume/pymongo_1626241226910/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt